# {{PERSON_NAME}}

## Overview

**Relationship**: Colleague | Friend | Family | Manager | Client | Other  
**Context**: *Where/how you know them*


## Recent Interactions

### {{DATE}}


## Action Items
- [ ] 


## Topics to Discuss


## Notes


---

*Track conversations and relationships here.*

